@@ -149,8 +149,8 @@ else:
             # Warn about function-scoped fixtures, excluding autouse fixtures because
             # the advice is probably not actionable and the status quo seems OK...
             # See https://github.com/HypothesisWorks/hypothesis/issues/377 for detail.
-            msg = item.nodeid + (
-                " uses the %r fixture, which is reset between function calls but not "
+            msg = (
+                "%s uses the %r fixture, which is reset between function calls but not "
                 "between test cases generated by `@given(...)`.  You can change it to "
                 "a module- or session-scoped fixture if it is safe to reuse; if not "
                 "we recommend using a context manager inside your test function.  See "
@@ -167,7 +167,9 @@ else:
                     if fx.argname in argnames:
                         active_fx = item._request._get_active_fixturedef(fx.argname)
                         if active_fx.scope == "function":
-                            note_deprecation(msg % (fx.argname,), since="2020-02-29")
+                            note_deprecation(
+                                msg % (item.nodeid, fx.argname), since="2020-02-29"
+                            )
 
             if item.get_closest_marker("parametrize") is not None:
                 # Give every parametrized test invocation a unique database key
